@@ -20,7 +20,6 @@ You should have received a copy of the GNU General Public License
 along with APAV.  If not, see <http://www.gnu.org/licenses/>.
 """
 
-from __future__ import annotations
 from apav.utils.validate import AbstractMethodError
 from typing import TYPE_CHECKING
 
@@ -32,7 +31,8 @@ class AnalysisBase:
     """
     Superclass for analysis classes
     """
-    def __init__(self, roi: Roi):
+
+    def __init__(self, roi: "Roi"):
         self.__roi = roi
         self._update_suppress = True
 
