@@ -32,25 +32,28 @@ from apav.core.multipleevent import MultipleEventExtractor, get_mass_indices
 from apav.core.histogram import histogram2d_binwidth
 from apav import RangeCollection, Range
 from apav.core.roi import DummyRoiHistogram, Roi
-from apav.visualization.factory import vfactory
+from apav.visualization import plotting
 from apav.analysis.base import AnalysisBase
 from apav.utils import validate
 from apav.utils.hinting import *
 from apav.analysis.background import BackgroundCollection, Background
-from apav.analysis import models
+from apav.utils.logging import log
 
 
 class CorrelationHistogram(AnalysisBase):
     """
     Statistical analysis of the correlation evaporation by ion pair histograms
     """
-    def __init__(self,
-                 roi: Roi,
-                 extents: Tuple[Tuple, Tuple] = ((0, 200), (0, 200)),
-                 bin_width: float = 0.1,
-                 multiplicity: Union[int, str] = 2,
-                 symmetric: bool = False,
-                 flip: bool = False):
+
+    def __init__(
+        self,
+        roi: Roi,
+        extents: Tuple[Tuple, Tuple] = ((0, 200), (0, 200)),
+        bin_width: Number = 0.1,
+        multiplicity: Union[int, str] = 2,
+        symmetric: bool = False,
+        flip: bool = False,
+    ):
         """
         Correlation histograms are computed by forming all ion pairs in given multiple-events. The correlation histogram
         may be computed using any multiplicity "order", for example creating histograms from the 2nd and 5th order
@@ -168,14 +171,14 @@ class CorrelationHistogram(AnalysisBase):
     @property
     def flip(self) -> bool:
         """
-        Whether or not the histogram was flipped (transposed)
+        Whether the histogram was flipped (transposed)
         """
         return self._flip
 
     @flip.setter
     def flip(self, new: bool):
         """
-        Set flip, whether or not the histogram has ion 1 on the y and ion 2 on the x
+        Set flip, whether the histogram has ion 1 on the y and ion 2 on the x
         """
         self._flip = validate.boolean(new)
         self._process()
@@ -225,7 +228,7 @@ class CorrelationHistogram(AnalysisBase):
         `export` function for saving the histogram in a format suitable for conventional plotting.
 
         """
-        widget = vfactory.make("interactive_correlation_histogram_plot", self)
+        widget = plotting.CorrelationHistogramPlot(self)
         return widget
 
     def export(self, path: str):
@@ -240,14 +243,17 @@ class RangedMassSpectrum(AnalysisBase):
     """
     Uncorrected ranged mass spectrum analysis
     """
-    def __init__(self,
-                 roi: Roi,
-                 ranges: RangeCollection,
-                 bin_width: float = 0.01,
-                 decompose: bool = False,
-                 percent: bool = False,
-                 upper: float = 200,
-                 multiplicity: Union[int, str] = "all"):
+
+    def __init__(
+        self,
+        roi: Roi,
+        ranges: RangeCollection,
+        bin_width: Number = 0.01,
+        decompose: bool = False,
+        percent: bool = False,
+        upper: Number = 200,
+        multiplicity: Union[int, str] = "all",
+    ):
         """
         This class is used for performing mass spectrum quantification on uncorrected mass histograms. No background
         subtractions are performed, see :class:`NoiseCorrectedMassSpectrum` and :class:`LocalBkgCorrectedMassSpectrum` for
@@ -283,16 +289,13 @@ class RangedMassSpectrum(AnalysisBase):
 
         # The mass_histogram is not strictly necessary in the quantification scheme for this class, but we use it
         # for plotting the ranges and for derived classes
-        self._histogram = self.roi.mass_histogram(self.bin_width,
-                                                  multiplicity=multiplicity,
-                                                  norm=False,
-                                                  upper=upper)
+        self._histogram = self.roi.mass_histogram(self.bin_width, multiplicity=multiplicity, norm=False, upper=upper)
         self._results_dict = None
         self._preprocess()
         self._process()
 
     @property
-    def upper(self) -> float:
+    def upper(self) -> Number:
         """
         Get the upper limit of the calculated histogram
         """
@@ -336,7 +339,7 @@ class RangedMassSpectrum(AnalysisBase):
         return self._multiplicity
 
     @property
-    def bin_width(self) -> float:
+    def bin_width(self) -> Number:
         """
         Get the bin width in Da
         """
@@ -402,19 +405,19 @@ class RangedMassSpectrum(AnalysisBase):
             ion_counts[rng.formula] += ranged_counts
 
             for element, number in rng.ion.comp_dict.items():
-                atomic_counts[element.symbol] += number*ranged_counts
+                atomic_counts[element.symbol] += number * ranged_counts
 
         # Ionic quantification
         ion_total = sum(ion_counts.values())
         ionic_quant = {}
         for ion, count in ion_counts.items():
-            ionic_quant[ion] = norm*count/ion_total
+            ionic_quant[ion] = norm * count / ion_total
 
         # Atomic quantification
         atomic_total = sum(atomic_counts.values())
         atomic_quant = {}
         for element, count in atomic_counts.items():
-            atomic_quant[element] = norm*count/atomic_total
+            atomic_quant[element] = norm * count / atomic_total
 
         quant = OrderedDict()
         if self.decompose is False:
@@ -430,7 +433,7 @@ class RangedMassSpectrum(AnalysisBase):
         """
         Get a plot to visualize the mass spectrum
         """
-        plt = vfactory.make("mass_spectrum_plot_ranged", self)
+        plt = plotting.MassSpectrumPlotRanged(self)
         return plt
 
 
@@ -438,11 +441,14 @@ class NoiseCorrectedMassSpectrum(RangedMassSpectrum):
     """
     Ranged mass spectrum analysis with correction for random noise background
     """
-    def __init__(self,
-                 roi: Roi,
-                 ranges: RangeCollection,
-                 noise_background: Background = Background((0.1, 0.75), model=PowerLawModel()),
-                 **kwargs):
+
+    def __init__(
+        self,
+        roi: Roi,
+        ranges: RangeCollection,
+        noise_background: Background = Background((0.1, 0.75), model=PowerLawModel()),
+        **kwargs,
+    ):
         """
         This class performs mass spectrum quantification on mass histograms after removing background from random
         noise. I.e. this noise is corrected by fitting a background model to the initial portion of the mass spectrum,
@@ -466,21 +472,14 @@ class NoiseCorrectedMassSpectrum(RangedMassSpectrum):
         super().__init__(roi, ranges, **kwargs)
 
     @classmethod
-    def from_array(cls,
-                   x: ndarray,
-                   y: ndarray,
-                   ranges: RangeCollection,
-                   decompose: bool = False,
-                   percent: bool = False):
+    def from_array(
+        cls, x: ndarray, y: ndarray, ranges: RangeCollection, decompose: bool = False, percent: bool = False
+    ):
         """
         Create the :class:`NoiseCorrectedMassSpectrum` from a numpy array (of a mass spectrum) instead of a :class:`Roi`
         """
         binwidth = x[1] - x[0]
-        retn = cls(DummyRoiHistogram(x, y),
-                   ranges,
-                   decompose=decompose,
-                   percent=percent,
-                   bin_width=binwidth)
+        retn = cls(DummyRoiHistogram(x, y), ranges, decompose=decompose, percent=percent, bin_width=binwidth)
 
         return retn
 
@@ -541,7 +540,7 @@ class NoiseCorrectedMassSpectrum(RangedMassSpectrum):
         """
         Get a interactive plot of the noise corrected mass spectrum.
         """
-        plt = vfactory.make("mass_spectrum_plot_noise_corrected", self)
+        plt = plotting.MassSpectrumPlotNoiseCorrected(self)
         return plt
 
 
@@ -549,12 +548,15 @@ class LocalBkgCorrectedMassSpectrum(NoiseCorrectedMassSpectrum):
     """
     Ranged mass spectrum analysis with correction for random noise and local background subtraction
     """
-    def __init__(self,
-                 roi: Roi,
-                 ranges: RangeCollection,
-                 local_background: BackgroundCollection,
-                 show_warnings: bool = False,
-                 **kwargs):
+
+    def __init__(
+        self,
+        roi: Roi,
+        ranges: RangeCollection,
+        local_background: BackgroundCollection,
+        show_warnings: bool = False,
+        **kwargs,
+    ):
         """
         This class performs mass spectrum quantification correcting for random noise background, as well as local
         background subtraction for isotopic peaks.
@@ -581,7 +583,7 @@ class LocalBkgCorrectedMassSpectrum(NoiseCorrectedMassSpectrum):
         :param ranges: RangeCollection defining mass ranges
         :param local_background: BackgroundCollection defining background model
         :param noise_background: Background defining the random noise background
-        :param disable_warnings: Disable warnings (such as when a range does has not been assigned a background)
+        :param disable_warnings: Disable warnings (such as when a range has not been assigned a background)
         :param **kwargs: Keyword arguments passed to :class:`NoiseCorrectedMassSpectrum` constructor
         """
         self._local_bkg = local_background
@@ -591,25 +593,29 @@ class LocalBkgCorrectedMassSpectrum(NoiseCorrectedMassSpectrum):
         super().__init__(roi, ranges, **kwargs)
 
     @classmethod
-    def from_array(cls,
-                   x: ndarray,
-                   y: ndarray,
-                   ranges: RangeCollection,
-                   background: BackgroundCollection,
-                   decompose: bool = False,
-                   percent: bool = False):
+    def from_array(
+        cls,
+        x: ndarray,
+        y: ndarray,
+        ranges: RangeCollection,
+        background: BackgroundCollection,
+        decompose: bool = False,
+        percent: bool = False,
+    ):
         """
         Mass spectrum analysis from an array
         """
         # Call constructor with a dummy roi
         binwidth = x[1] - x[0]
-        retn = cls(DummyRoiHistogram(x, y),
-                   ranges,
-                   background,
-                   decompose=decompose,
-                   percent=percent,
-                   bin_width=binwidth,
-                   cutoff=x[-1])
+        retn = cls(
+            DummyRoiHistogram(x, y),
+            ranges,
+            background,
+            decompose=decompose,
+            percent=percent,
+            bin_width=binwidth,
+            cutoff=x[-1],
+        )
 
         return retn
 
@@ -671,8 +677,10 @@ class LocalBkgCorrectedMassSpectrum(NoiseCorrectedMassSpectrum):
             else:
                 sig_y[idx] = y[idx]
                 if self.show_warnings:
-                    warn(f"No background could be matched to {rng.ion.hill_formula} from {rng.lower}-{rng.upper} Da."
-                         f" This range will not be background corrected.")
+                    log.warn(
+                        f"No background could be matched to {rng.ion.hill_formula} from {rng.lower}-{rng.upper} Da."
+                        f" This range will not be background corrected."
+                    )
 
         self.__local_bkg_hist = (x, bkg_y)
         self.__corrected_hist = (x, sig_y)
@@ -681,5 +689,5 @@ class LocalBkgCorrectedMassSpectrum(NoiseCorrectedMassSpectrum):
         """
         Get an interactive plot showing the background fits
         """
-        plt = vfactory.make("mass_spectrum_plot_local_bkg_corrected", self)
+        plt = plotting.MassSpectrumPlotLocalBkgCorrected(self)
         return plt
