@@ -37,23 +37,132 @@ from apav.utils.hinting import *
 from apav.utils import validate
 
 
-_syms = ['Ac', 'Ag', 'Al', 'Am', 'Ar', 'As', 'At', 'Au', 'B', 'Ba', 'Be', 'Bh', 'Bi', 'Bk', 'Br', 'C', 'Ca', 'Cd', 'Ce',
-         'Cf', 'Cl', 'Cm',
-         'Cn', 'Co', 'Cr', 'Cs', 'Cu', 'Db', 'Ds', 'Dy', 'Er', 'Es', 'Eu', 'F', 'Fe', 'Fl', 'Fm', 'Fr', 'Ga', 'Gd',
-         'Ge', 'H', 'He', 'Hf', 'Hg', 'Ho',
-         'Hs', 'I', 'In', 'Ir', 'K', 'Kr', 'La', 'Li', 'Lr', 'Lu', 'Lv', 'Mc', 'Md', 'Mg', 'Mn', 'Mo', 'Mt', 'N', 'Na',
-         'Nb', 'Nd', 'Ne',
-         'Nh', 'Ni', 'No', 'Np', 'O', 'Og', 'Os', 'P', 'Pa', 'Pb', 'Pd', 'Pm', 'Po', 'Pr', 'Pt', 'Pu', 'Ra', 'Rb', 'Re',
-         'Rf', 'Rg', 'Rh',
-         'Rn', 'Ru', 'S', 'Sb', 'Sc', 'Se', 'Sg', 'Si', 'Sm', 'Sn', 'Sr', 'Ta', 'Tb', 'Tc', 'Te', 'Th', 'Ti', 'Tl',
-         'Tm', 'Ts', 'U', 'V',
-         'W', 'Xe', 'Y', 'Yb', 'Zn', 'Zr']
+_syms = [
+    "Ac",
+    "Ag",
+    "Al",
+    "Am",
+    "Ar",
+    "As",
+    "At",
+    "Au",
+    "B",
+    "Ba",
+    "Be",
+    "Bh",
+    "Bi",
+    "Bk",
+    "Br",
+    "C",
+    "Ca",
+    "Cd",
+    "Ce",
+    "Cf",
+    "Cl",
+    "Cm",
+    "Cn",
+    "Co",
+    "Cr",
+    "Cs",
+    "Cu",
+    "Db",
+    "Ds",
+    "Dy",
+    "Er",
+    "Es",
+    "Eu",
+    "F",
+    "Fe",
+    "Fl",
+    "Fm",
+    "Fr",
+    "Ga",
+    "Gd",
+    "Ge",
+    "H",
+    "He",
+    "Hf",
+    "Hg",
+    "Ho",
+    "Hs",
+    "I",
+    "In",
+    "Ir",
+    "K",
+    "Kr",
+    "La",
+    "Li",
+    "Lr",
+    "Lu",
+    "Lv",
+    "Mc",
+    "Md",
+    "Mg",
+    "Mn",
+    "Mo",
+    "Mt",
+    "N",
+    "Na",
+    "Nb",
+    "Nd",
+    "Ne",
+    "Nh",
+    "Ni",
+    "No",
+    "Np",
+    "O",
+    "Og",
+    "Os",
+    "P",
+    "Pa",
+    "Pb",
+    "Pd",
+    "Pm",
+    "Po",
+    "Pr",
+    "Pt",
+    "Pu",
+    "Ra",
+    "Rb",
+    "Re",
+    "Rf",
+    "Rg",
+    "Rh",
+    "Rn",
+    "Ru",
+    "S",
+    "Sb",
+    "Sc",
+    "Se",
+    "Sg",
+    "Si",
+    "Sm",
+    "Sn",
+    "Sr",
+    "Ta",
+    "Tb",
+    "Tc",
+    "Te",
+    "Th",
+    "Ti",
+    "Tl",
+    "Tm",
+    "Ts",
+    "U",
+    "V",
+    "W",
+    "Xe",
+    "Y",
+    "Yb",
+    "Zn",
+    "Zr",
+]
 
 _comp_re = re.compile(r"([A-Z][a-z]?)([0-9]*)")
 
 
 class UnknownElement:
-    def __init__(self, symbol):
+    def __init__(self, symbol: str):
         self._symbol = symbol
 
     def __repr__(self):
@@ -108,7 +217,7 @@ def str2composition(formula: str) -> Dict[Element, int]:
     if len(matches) == 0:
         raise ValueError("Formula cannot be null")
 
-    all_matches = "".join([i[0]+i[1] for i in matches])
+    all_matches = "".join([i[0] + i[1] for i in matches])
 
     # If the original formula is not the same length as the regex matches then the formula is invalid
     if len(all_matches) != len(formula):
@@ -199,24 +308,24 @@ class Ion:
         return [i for i in self.comp_dict.keys()]
 
     @property
-    def number(self) -> Real:
+    def number(self) -> Number:
         """
         Get the cumulative atomic number of the ion
         """
         retn = 0
         for elem, count in self._comp_dict.items():
-            retn += elem.number*count
+            retn += elem.number * count
 
         return retn
 
     @property
-    def mass(self) -> Real:
+    def mass(self) -> Number:
         """
         Get the cumulative atomic mass of the ion
         """
         retn = 0
         for elem, count in self._comp_dict.items():
-            retn += elem.mass*count
+            retn += elem.mass * count
 
         return retn
 
@@ -252,7 +361,7 @@ class Ion:
 
     def all_real_elements(self) -> bool:
         """
-        Determine if any elements in the composition are not real (place holder or unknown elements)
+        Determine if any elements in the composition are not Number (place holder or unknown elements)
         """
         return all(not isinstance(i, UnknownElement) for i in self.elements)
 
@@ -261,11 +370,8 @@ class Isotope:
     """
     A single isotope
     """
-    def __init__(self,
-                 ion: Ion,
-                 number: int,
-                 mass: float,
-                 abundance: float):
+
+    def __init__(self, ion: Ion, number: int, mass: Number, abundance: Number):
         """
         This class defines a single isotopic species, defined by composition, charge, mass, and absolute abundance.
         These values must be provided manually, see `IsotopeSeries` for calculating isotope distributions (which uses
@@ -290,10 +396,12 @@ class Isotope:
         return f"Isotope: {self.ion.hill_formula} +{self.charge} {self.number} @ {n.round(self.mass, 3)} Da {n.round(self.abundance*100, 2)} %"
 
     def __eq__(self, other):
-        if self.ion == other.ion and \
-                self.number == other.number and \
-                self.mass == other.mass and \
-                self.abundance == other.abundance:
+        if (
+            self.ion == other.ion
+            and self.number == other.number
+            and self.mass == other.mass
+            and self.abundance == other.abundance
+        ):
             return True
         else:
             return False
@@ -313,14 +421,14 @@ class Isotope:
         return self._number
 
     @property
-    def mass(self) -> float:
+    def mass(self) -> Number:
         """
         Get the atomic mass of the isotope
         """
         return self._mass
 
     @property
-    def abundance(self) -> float:
+    def abundance(self) -> Number:
         """
         Get the absolute abundance of the isotope
         """
@@ -338,10 +446,8 @@ class IsotopeSeries:
     """
     Compute isotopic distributions
     """
-    def __init__(self,
-                 *args,
-                 isotopes: Optional[List[Isotope]] = None,
-                 threshold: Real = 0.01):
+
+    def __init__(self, *args, isotopes: Optional[List[Isotope]] = None, threshold: Number = 0.01):
         """
         This class computes isotopic distributions of arbitrary elemental or molecular compositions. The only physical
         requirement is that the charge is not 0.
@@ -363,7 +469,7 @@ class IsotopeSeries:
         is not guaranteed to be unity. If this is important, the threshold can be set to 0 to get all isotopologues, or
         consider working with relative abundances instead.
 
-        This computation works for both elemental ions as well as molecular ions, i.e.
+        This computation works for both elemental and molecular ions, i.e.
 
         >>> IsotopeSeries("CuO2", 2)
         >>> IsotopeSeries("Cu", 3)
@@ -416,7 +522,10 @@ class IsotopeSeries:
         thresh_str = f", threshold: {self.threshold*100}%" if self.threshold else ", all isotopes"
         retn = f"IsotopeSeries: {self.ion.hill_formula} +{self.ion.charge}{thresh_str}\n"
         max_val = max(i.abundance for i in self.isotopes)
-        data = [[i+1, iso.ion.hill_formula, iso.number, iso.mass, iso.abundance*100, iso.abundance/max_val*100] for i, iso in enumerate(self.isotopes)]
+        data = [
+            [i + 1, iso.ion.hill_formula, iso.number, iso.mass, iso.abundance * 100, iso.abundance / max_val * 100]
+            for i, iso in enumerate(self.isotopes)
+        ]
         table = tab.tabulate(data, ("", "Ion", "Isotope", "Mass", "Abs. abundance %", "Rel. abundance %"))
         retn += table
         return retn
@@ -477,14 +586,14 @@ class IsotopeSeries:
         return self._isotopes
 
     @property
-    def threshold(self) -> Real:
+    def threshold(self) -> Number:
         """
         Get the threshold used for computing the isotopes
         """
         return self._threshold
 
     @threshold.setter
-    def threshold(self, new: Real):
+    def threshold(self, new: Number):
         """
         Set the threshold. This represents the absolute abundance limit for the computed isotopes
         :param new: the new absolute abundance limit/threshold
@@ -509,8 +618,11 @@ class IsotopeSeries:
         Initialize the isotopes from an elemental ion (1 element 1 atom)
         """
         pt_elem = pt.elements.symbol(self.ion.elements[0].symbol)
-        isos = [Isotope(self.ion, pt_elem[i].isotope, pt_elem[i].mass / self.ion.charge, pt_elem[i].abundance / 100) for
-                i in pt_elem.isotopes if pt_elem[i].abundance > 0]
+        isos = [
+            Isotope(self.ion, pt_elem[i].isotope, pt_elem[i].mass / self.ion.charge, pt_elem[i].abundance / 100)
+            for i in pt_elem.isotopes
+            if pt_elem[i].abundance > 0
+        ]
         self._init_isotopes_as_manual(isos)
         assert self._is_unity
 
@@ -562,15 +674,15 @@ class IsotopeSeries:
             for elem, isos in iso_dict.items():
                 elem_amount = math.factorial(self.ion.comp_str_dict[elem])
                 isotope_amounts = n.prod([math.factorial(i[1]) for i in isos])
-                isotope_abundances = n.prod([i[0].abundance**(i[1]) for i in isos])
-                elem_parts.append(elem_amount*isotope_abundances/isotope_amounts)
+                isotope_abundances = n.prod([i[0].abundance ** (i[1]) for i in isos])
+                elem_parts.append(elem_amount * isotope_abundances / isotope_amounts)
             rslts.append(n.prod(elem_parts))
 
         # Make the Isotope objects
         new_isos = []
         for isos, abundance in zip(unique_isos, rslts):
             number = sum(i.number for i in isos)
-            mass = sum(i.mass for i in isos)/n.abs(self.ion.charge)
+            mass = sum(i.mass for i in isos) / n.abs(self.ion.charge)
             newiso = Isotope(self.ion, number, mass, abundance)
             new_isos.append(newiso)
 
@@ -582,4 +694,3 @@ class IsotopeSeries:
         For internal checking when all isotopic abundances equal unity
         """
         return n.isclose(sum(i.abundance for i in self._all_isotopes), 1, 1e-10)
-
