@@ -31,22 +31,56 @@ import numpy as n
 import numpy.linalg as la
 
 from apav.utils import validate
-from apav.utils.helpers import unique_int8, minmax
+from apav.utils.helpers import unique_vals, minmax, array2native_byteorder
 from apav.core.multipleevent import get_mass_indices
 from apav.utils.validate import NoMultiEventError, NoDetectorInfoError, NoTOFError
 from apav.core.histogram import histogram1d
 from apav.utils.hinting import *
-from apav.visualization.factory import vfactory
+from apav.visualization import plotting
+from apav.utils.logging import log
+
+
+_bf = ">f4"
+_bi = ">i4"
+_lf = "<f4"
+_li = "<i4"
 
 
 class Roi:
     """
     High level container for operating on atom probe data sets.
     """
-    def __init__(self,
-                 xyz: ndarray,
-                 mass: ndarray,
-                 misc: dict = None):
+
+    _ato_dtype = n.dtype(
+        [
+            ("xyz", (_lf, 3)),
+            ("mass", _lf),
+            ("cluster_id", _li),
+            ("pulse_number", _lf),
+            ("dc_voltage", _lf),  # kV
+            ("tof", _lf),
+            ("det_x", _lf),  # cm
+            ("det_y", _lf),  # cm
+            ("pulse_voltage", _lf),  # kV
+            ("vvolt", _lf),
+            ("fourier_r", _lf),
+            ("fourier_i", _lf),
+        ]
+    )
+
+    _epos_dtype = [
+        ("xyz", (_bf, 3)),
+        ("mass", _bf),
+        ("tof", _bf),
+        ("dc_voltage", _bf),
+        ("pulse_voltage", _bf),
+        ("det_x", _bf),
+        ("det_y", _bf),
+        ("psl", _bi),
+        ("ipp", _bi),
+    ]
+
+    def __init__(self, xyz: ndarray, mass: ndarray, misc: dict = None):
         """
         This data structure is the entry point for loading or constructing atom probe data set for use with other
         components of APAV. Fictitious atom probe data set can be created by providing the required XYZ and mass/charge
@@ -113,7 +147,7 @@ class Roi:
         if not self.has_multiplicity_info():
             raise NoMultiEventError()
         elif self.has_multiplicity_info() and self._multiplicities is None:
-            self._multiplicities = unique_int8(self.misc["ipp"])
+            self._multiplicities = unique_vals(self.misc["ipp"])
             self._multiplicities.sort()
             self._multiplicities = self._multiplicities[1:]
         return self._multiplicities
@@ -150,7 +184,7 @@ class Roi:
             return {key: value[self._mask] for key, value in self._misc.items()}
 
     @property
-    def counts(self) -> float:
+    def counts(self) -> int:
         """
         Get the total number of detected ions
         """
@@ -179,10 +213,10 @@ class Roi:
         if self._xyz_extents is None:
             # The 3 major 64-bit operating systems are little endian, so we must byte swap before using the numba
             # accelerated minmax function if the roi was originally from a pos or epos file (these files are big endian)
-            if self._from_pos_or_epos is True:
-                self._xyz_extents = tuple(minmax(self.xyz[:, i].byteswap().view(n.float32)) for i in range(self.xyz.shape[1]))
-            else:
-                self._xyz_extents = tuple(minmax(self.xyz[:, i]) for i in range(self.xyz.shape[1]))
+            # if self._from_pos_or_epos is True:
+            #     self._xyz_extents = tuple(minmax(self.xyz[:, i].byteswap().view()) for i in range(self.xyz.shape[1]))
+            # else:
+            self._xyz_extents = tuple(minmax(self.xyz[:, i]) for i in range(self.xyz.shape[1]))
         return self._xyz_extents
 
     @property
@@ -193,7 +227,7 @@ class Roi:
         return n.mean(self.xyz, axis=0)
 
     @property
-    def detector_extents(self) -> (tuple, tuple):
+    def detector_extents(self) -> Tuple[Tuple[float, float], Tuple[float, float]]:
         """
         Get the min/max spatial values in x/y detector coordinates
         """
@@ -218,7 +252,7 @@ class Roi:
 
     def has_tof_info(self) -> bool:
         """
-        Get if the the Roi has time of flight information
+        Get if the Roi has time of flight information
         """
         return "tof" in self.misc.keys()
 
@@ -230,13 +264,13 @@ class Roi:
         :param filepath: Path to apt file
         :param verbose: Print the structure of the apt file as it is read (for debug purposes)
         """
-
         validate.file_exists(filepath)
+        log.info("Reading apt file: {}".format(filepath))
 
         class RelType(Enum):
             REL_UNKNOWN = 0
             ONE_TO_ONE = 1
-            INDEXED = 2,
+            INDEXED = (2,)
             UNRELATED = 3
             ONE_TO_MANY = 4
 
@@ -268,17 +302,9 @@ class Roi:
             if rec_dtype in (RecordDataType.UINT, RecordDataType.CHARSTRING):
                 raise ValueError("Cannot map to UINT or CHARSTRING")
 
-            int_map = {
-                8: n.int8,
-                16: n.int16,
-                32: n.int32,
-                64: n.int64
-            }
+            int_map = {8: n.int8, 16: n.int16, 32: n.int32, 64: n.int64}
 
-            float_map = {
-                32: n.float32,
-                64: n.float64
-            }
+            float_map = {32: n.float32, 64: n.float64}
 
             if rec_dtype == RecordDataType.INT:
                 return int_map[size]
@@ -288,13 +314,7 @@ class Roi:
                 raise ValueError(f"Unexpected record data type {rec_dtype}")
 
         # Maps the apt format data type to str format needed for struct.unpack
-        dtype2fmt = {
-            Dtype.int32: "i",
-            Dtype.int64: "q",
-            Dtype.char: "c",
-            Dtype.filetime: "Q",
-            Dtype.wchar_t: "c"
-        }
+        dtype2fmt = {Dtype.int32: "i", Dtype.int64: "q", Dtype.char: "c", Dtype.filetime: "Q", Dtype.wchar_t: "c"}
 
         # Maps the apt format data type to python data type
         dtype2constr = {
@@ -302,22 +322,21 @@ class Roi:
             Dtype.int64: int,
             Dtype.char: lambda x: x.decode("utf-8"),
             Dtype.wchar_t: lambda x: x.decode("utf-16"),
-            Dtype.filetime: int
+            Dtype.filetime: int,
         }
 
         with open(filepath, "rb") as dat:
-            def read_chunk(dtype: Dtype,
-                           count: int = 1,
-                           start: Union[None, int] = None) -> Union[Tuple[Any], Any]:
+
+            def read_chunk(dtype: Dtype, count: int = 1, start: Union[None, int] = None) -> Union[Tuple[Any], Any]:
                 if isinstance(start, int):
                     dat.seek(start)
 
-                fmt = dtype2fmt[dtype]*count
+                fmt = dtype2fmt[dtype] * count
                 constructor = dtype2constr[dtype]
                 dtype_size = dtype.value
 
                 if dtype in (Dtype.wchar_t, Dtype.char):
-                    return constructor(dat.read(dtype_size*count)).replace("\x00", "")
+                    return constructor(dat.read(dtype_size * count)).replace("\x00", "")
                 else:
                     retn = struct.unpack("<" + fmt, dat.read(dtype_size * count))
 
@@ -351,7 +370,7 @@ class Roi:
             while True:
                 sec_sig = read_chunk(Dtype.char, 4, section_start)
 
-                if sec_sig == '':
+                if sec_sig == "":
                     # EOF reached
                     break
 
@@ -367,18 +386,18 @@ class Roi:
                 sec_rel_type = RelType(read_chunk(Dtype.int32))
                 is_one_to_one = sec_rel_type == RelType.ONE_TO_ONE
                 if not is_one_to_one:
-                    warn(f"APAV does not handle REL_TYPE != ONE_TO_ONE, section \"{sec_type}\" will be ignored")
+                    warn(f'APAV does not handle REL_TYPE != ONE_TO_ONE, section "{sec_type}" will be ignored')
                     skip_sec = True
 
                 sec_rec_type = RecordType(read_chunk(Dtype.int32))
                 is_fixed_size = sec_rec_type == RecordType.FIXED_SIZE
                 if not is_fixed_size:
-                    warn(f"APAV does not handle RECORD_TYPE != FIXED_SIZE, section \"{sec_type}\" will be ignored")
+                    warn(f'APAV does not handle RECORD_TYPE != FIXED_SIZE, section "{sec_type}" will be ignored')
                     skip_sec = True
 
                 sec_rec_dtype = RecordDataType(read_chunk(Dtype.int32))
                 if sec_rec_dtype in (RecordDataType.DT_UNKNOWN, RecordDataType.OTHER, RecordDataType.CHARSTRING):
-                    warn(f"APAV does not handle RECORD_TYPE == {sec_rec_dtype}, section \"{sec_type}\" will be ignored")
+                    warn(f'APAV does not handle RECORD_TYPE == {sec_rec_dtype}, section "{sec_type}" will be ignored')
                     skip_sec = True
 
                 sec_dtype_size = read_chunk(Dtype.int32)
@@ -404,13 +423,15 @@ class Roi:
                     print(f"\tSection byte count: {sec_byte_count}")
 
                 if not skip_sec:
-                    columns = int(sec_rec_size/(sec_dtype_size/8))
+                    columns = int(sec_rec_size / (sec_dtype_size / 8))
                     records = int(sec_rec_count)
-                    count = records*columns
-                    in_data = n.fromfile(filepath,
-                                         record_dtype2numpy_dtype(sec_rec_dtype, sec_dtype_size),
-                                         count,
-                                         offset=section_start+sec_header_size)
+                    count = records * columns
+                    in_data = n.fromfile(
+                        filepath,
+                        record_dtype2numpy_dtype(sec_rec_dtype, sec_dtype_size),
+                        count,
+                        offset=section_start + sec_header_size,
+                    )
                     if columns > 1:
                         section_data[sec_type] = in_data.reshape(records, columns)
                     else:
@@ -421,14 +442,14 @@ class Roi:
         has_mass_data = "Mass" in section_data.keys()
         has_pos_data = "Position" in section_data.keys()
 
-        # Map some APT section names to names that APAV expects, otherwise the provided name is retained
+        # Map some APT section names to those that APAV expects, otherwise the provided name is retained
         name_map = {
             "Multiplicity": "ipp",
             "Time of Flight": "tof",
             "XDet_mm": "det_x",
             "YDet_mm": "det_y",
             "Voltage": "dc_voltage",
-            "Pulse Voltage": "pulse_voltage"
+            "Pulse Voltage": "pulse_voltage",
         }
 
         # Require mass and position data, clean up some sections, and account for possible duplicate sections (i.e.
@@ -467,10 +488,15 @@ class Roi:
         :param filepath: Path to pos file
         """
         validate.file_exists(filepath)
+        log.info("Reading pos file: {}".format(filepath))
 
         dtype = n.dtype(">f4")
         data = n.fromfile(filepath, dtype=dtype, sep="")
-        data.shape = (int(data.size/4), 4)
+        data.shape = (int(data.size / 4), 4)
+
+        # Data in epos files are big endian which most operating systems are not. Convert to native byte-order
+        # to prevent errors in compiled c extensions
+        data = array2native_byteorder(data)
 
         retn = cls(data[:, :3], data[:, 3])
         retn._filepath = filepath
@@ -485,32 +511,28 @@ class Roi:
         :param filepath: Path to epos file
         """
         validate.file_exists(filepath)
+        log.info("Reading epos file: {}".format(filepath))
 
-        f = ">f4"
-        i = ">i4"
-        dtype = n.dtype([("xyz", (f, 3)),
-                         ("mass", f),
-                         ("tof", f),
-                         ("dc_voltage", f),
-                         ("pulse_voltage", f),
-                         ("det_x", f),
-                         ("det_y", f),
-                         ("psl", i),
-                         ("ipp", i)])
+        data = n.fromfile(filepath, dtype=n.dtype(Roi._epos_dtype))
 
-        data = n.fromfile(filepath, dtype=dtype)
-        # data["dc_voltage"] *= 1000
-        # data["pulse_voltage"] *= 1000
+        # Data in epos files are big endian which most operating systems are not. Convert to little endian
+        # to prevent errors in compiled c extensions
+        data = array2native_byteorder(data)
+
+        retn = cls(
+            data["xyz"],
+            data["mass"],
+            {
+                "tof": data["tof"],
+                "dc_voltage": data["dc_voltage"],
+                "pulse_voltage": data["pulse_voltage"],
+                "det_x": data["det_x"],
+                "det_y": data["det_y"],
+                "psl": data["psl"],
+                "ipp": data["ipp"].astype(n.uint8),
+            },
+        )
 
-        retn = cls(data["xyz"],
-                   data["mass"],
-                   {"tof": data["tof"],
-                    "dc_voltage": data["dc_voltage"],
-                    "pulse_voltage": data["pulse_voltage"],
-                    "det_x": data["det_x"],
-                    "det_y": data["det_y"],
-                    "psl": data["psl"],
-                    "ipp": data["ipp"].astype(n.uint8)})
         retn._filepath = filepath
         retn._from_pos_or_epos = True
         return retn
@@ -523,25 +545,15 @@ class Roi:
         :param filepath: Path to ato file
         """
         validate.file_exists(filepath)
+        log.info("Reading ato file: {}".format(filepath))
 
         with open(filepath, "rb") as ato:
             ato.seek(8, os.SEEK_SET)
             f = "<f4"
             i = "<i4"
-            dtype = n.dtype([("xyz", (f, 3)),
-                             ("mass", f),
-                             ("cluster_id", i),
-                             ("pulse_number", f),
-                             ("dc_voltage", f),  # kV
-                             ("tof", f),
-                             ("det_x", f),  # cm
-                             ("det_y", f),  # cm
-                             ("pulse_voltage", f),  # kV
-                             ("vvolt", f),
-                             ("fourier_r", f),
-                             ("fourier_i", f)])
 
-            data = n.fromfile(ato, dtype=dtype)
+            data = n.fromfile(ato, dtype=Roi._ato_dtype)
+            data = array2native_byteorder(data)
 
         # Process some data to make units consistent and other cleaning
         pulsen = data["pulse_number"].copy().astype(n.int64)
@@ -555,21 +567,63 @@ class Roi:
 
         for j, startstop in enumerate(zip(begin, end)):
             start, stop = startstop
-            pulsen[start:stop+1] += j*2**24
+            pulsen[start : stop + 1] += j * 2**24
         data["pulse_number"] = pulsen
 
-        retn = cls(data["xyz"],
-                   data["mass"],
-                   {"tof": data["tof"],
-                    "dc_voltage": data["dc_voltage"],
-                    "pulse_voltage": data["pulse_voltage"],
-                    "pulse_number": data["pulse_number"],
-                    "det_x": data["det_x"],
-                    "det_y": data["det_y"],
-                    })
+        retn = cls(
+            data["xyz"],
+            data["mass"],
+            {
+                "tof": data["tof"],
+                "dc_voltage": data["dc_voltage"],
+                "pulse_voltage": data["pulse_voltage"],
+                "pulse_number": data["pulse_number"],
+                "det_x": data["det_x"],
+                "det_y": data["det_y"],
+            },
+        )
         retn._filepath = filepath
         return retn
 
+    def to_pos(self, filepath: str):
+        """
+        Write the roi to a standard pos file
+
+        :param filepath: path of the pos file
+        """
+        validate.dir_is_writable(filepath)
+
+        log.info("Writing pos file to: {}".format(filepath))
+
+        dtype = n.dtype(">f4")
+        out = n.hstack([self.xyz, self.mass[None].T]).astype(dtype)
+        out.tofile(filepath, sep="")
+
+    def to_epos(self, filepath: str):
+        """
+        Write the roi to a standard extended pos file
+
+        :param filepath: path of the epos file
+        """
+        validate.dir_is_writable(filepath)
+
+        epos_misc_entries = ["tof", "dc_voltage", "pulse_voltage", "det_x", "det_y", "psl", "ipp"]
+        if not all(i in self.misc.keys() for i in epos_misc_entries):
+            raise AttributeError("Roi does not contain the required misc keys to write to epos")
+
+        log.info("Writing epos file to: {}".format(filepath))
+        out = n.zeros(int(self.counts), dtype=Roi._epos_dtype)
+        out["xyz"] = self.xyz
+        out["mass"] = self.mass
+        out["tof"] = self.misc["tof"]
+        out["dc_voltage"] = self.misc["dc_voltage"]
+        out["pulse_voltage"] = self.misc["pulse_voltage"]
+        out["det_x"] = self.misc["det_x"]
+        out["det_y"] = self.misc["det_y"]
+        out["psl"] = self.misc["psl"]
+        out["ipp"] = self.misc["ipp"]
+        out.tofile(filepath, sep="")
+
     def memory_size(self) -> float:
         """
         Get the approximate memory footprint in Mb
@@ -580,7 +634,7 @@ class Roi:
         for i in self.misc.values():
             val += i.nbytes
 
-        return round(val/1024**2, 3)
+        return round(val / 1024**2, 3)
 
     def multiplicity_counts(self) -> Tuple[ndarray, ndarray]:
         """
@@ -600,26 +654,28 @@ class Roi:
 
         return self._multiplicity_counts
 
-    def multiplicity_percentage(self):
+    def multiplicity_percentage(self) -> Tuple[ndarray, ndarray]:
         """
         Get the statistical percentage of each degree of multiple-detector events
         """
         mult, counts = self.multiplicity_fraction()
-        return mult, counts*100
+        return mult, counts * 100
 
-    def multiplicity_fraction(self):
+    def multiplicity_fraction(self) -> Tuple[ndarray, ndarray]:
         """
         Get the statistical fraction of each degree of multiple-detector events
         """
         mult, counts = self.multiplicity_counts()
-        return mult, counts/counts.sum()
+        return mult, counts / counts.sum()
 
     @lru_cache(50)
-    def tof_histogram(self,
-                      bin_width: float = 1,
-                      multiplicity: Union[str, int] = "all",
-                      norm: Union[bool, Tuple[float, float]] = False,
-                      cutoff: float = 2000) -> (ndarray, ndarray):
+    def tof_histogram(
+        self,
+        bin_width: Number = 1,
+        multiplicity: Union[str, int] = "all",
+        norm: Union[bool, Tuple[Number, Number]] = False,
+        cutoff: float = 2000,
+    ) -> (ndarray, ndarray):
         """
         Get the time-of-flight histogram of the given Roi. This function is cached to increase speed under repeated
         calls.
@@ -664,12 +720,14 @@ class Roi:
         return edges, counts
 
     @lru_cache(50)
-    def mass_histogram(self,
-                       bin_width: float = 0.05,
-                       lower: float = 0,
-                       upper: float = 200,
-                       multiplicity: Union[str, int] = "all",
-                       norm: Union[bool, Tuple[float, float]] = False) -> (ndarray, ndarray):
+    def mass_histogram(
+        self,
+        bin_width: Number = 0.05,
+        lower: Number = 0,
+        upper: Number = 200,
+        multiplicity: Union[str, int] = "all",
+        norm: Union[bool, Tuple[Number, Number]] = False,
+    ) -> (ndarray, ndarray):
         """
         Get the mass/charge ratio histogram of the given Roi. This function is cached to increase speed under repeated
         calls.
@@ -718,7 +776,7 @@ class Roi:
         """
         Get an interactive plot of the mass spectrum of the Roi.
         """
-        return vfactory.make("mass_spectrum_plot", self)
+        return plotting.MassSpectrumPlot(self)
 
     def require_multihit_info(self):
         """
@@ -774,10 +832,8 @@ class RoiRectPrism(RoiSubsetType):
     """
     Creates a new roi from an existing roi, containing ions within a rectangular prism
     """
-    def __init__(self,
-                 parent: Roi,
-                 center: Tuple[float, float, float],
-                 widths: Tuple[float, float, float]):
+
+    def __init__(self, parent: Roi, center: Tuple[Number, Number, Number], widths: Tuple[Number, Number, Number]):
         """
         :param parent: Parent Roi to generate the subset from
         :param center: Geometric center to place the rectangular prism
@@ -792,22 +848,17 @@ class RoiRectPrism(RoiSubsetType):
         self._from_pos_or_epos = self._parent._from_pos_or_epos
 
         xc, yc, zc = center
-        dx, dy, dz = [width/2 for width in widths]
+        dx, dy, dz = [width / 2 for width in widths]
 
         # Axis boundaries
-        xext, yext, zext = (xc-dx, xc+dx), \
-                           (yc-dy, yc+dy), \
-                           (zc-dz, zc+dz)
+        xext, yext, zext = (xc - dx, xc + dx), (yc - dy, yc + dy), (zc - dz, zc + dz)
         xyz = self.xyz
 
         idx = n.argwhere((xext[0] < xyz[:, 0]) & (xyz[:, 0] < xext[1])).ravel()
         idx = idx[n.argwhere((yext[0] < xyz[idx][:, 1]) & (xyz[idx][:, 1] < yext[1])).ravel()]
         idx = idx[n.argwhere((zext[0] < xyz[idx][:, 2]) & (xyz[idx][:, 2] < zext[1])).ravel()]
 
-        # First filter out everything outside of the bounding box
-        # idx = n.argwhere((xext[0] < xyz[:, 0]) & (xyz[:, 0] < xext[1]) &
-        #                  (yext[0] < xyz[:, 1]) & (xyz[:, 1] < yext[1]) &
-        #                  (zext[0] < xyz[:, 2]) & (xyz[:, 2] < zext[1])).ravel()
+        log.debug("Created {} with:\n\tcenter = {}\n\twidths = {}".format(self.__class__, center, widths))
 
         self._mask = idx
 
@@ -816,10 +867,8 @@ class RoiSphere(RoiSubsetType):
     """
     Creates a new roi from an existing roi, containing ions within a sphere
     """
-    def __init__(self,
-                 parent: Roi,
-                 center: Tuple[float, float, float],
-                 radius: float):
+
+    def __init__(self, parent: Roi, center: Tuple[Number, Number, Number], radius: Number):
         """
         :param parent: Parent Roi to generate the subset from
         :param center: Geometric center of the sphere
@@ -836,24 +885,20 @@ class RoiSphere(RoiSubsetType):
         xc, yc, zc = center
 
         # Axis boundaries
-        xext, yext, zext = (xc-radius, xc+radius), \
-                           (yc-radius, yc+radius), \
-                           (zc-radius, zc+radius)
+        xext, yext, zext = (xc - radius, xc + radius), (yc - radius, yc + radius), (zc - radius, zc + radius)
         xyz = self.xyz
 
-        # First filter out everything outside of the bounding box
+        # First filter out everything outside the bounding box
         idx = n.argwhere((xext[0] < xyz[:, 0]) & (xyz[:, 0] < xext[1])).ravel()
         idx = idx[n.argwhere((yext[0] < xyz[idx][:, 1]) & (xyz[idx][:, 1] < yext[1])).ravel()]
         idx = idx[n.argwhere((zext[0] < xyz[idx][:, 2]) & (xyz[idx][:, 2] < zext[1])).ravel()]
 
-        # idx = n.argwhere((xext[0] < xyz[:, 0]) & (xyz[:, 0] < xext[1]) &
-        #                  (yext[0] < xyz[:, 1]) & (xyz[:, 1] < yext[1]) &
-        #                  (zext[0] < xyz[:, 2]) & (xyz[:, 2] < zext[1])).ravel()
-
         # Then filter out everything not within the sphere radius
-        r = la.norm((xyz[idx]-center), axis=1)
+        r = la.norm((xyz[idx] - center), axis=1)
         idx = idx[n.argwhere(r < radius).ravel()]
 
+        log.debug(f"Created {self.__class__} with:\n\tcenter = {center}\n\tradius = {radius}")
+
         self._mask = idx
 
 
@@ -861,12 +906,10 @@ class RoiCylinder(RoiSubsetType):
     """
     Creates a new roi from an existing roi, containing ions within a cylinder
     """
-    def __init__(self,
-                 parent: Roi,
-                 center: Tuple[float, float, float],
-                 radius: float,
-                 height: float,
-                 axis: str = "z"):
+
+    def __init__(
+        self, parent: Roi, center: Tuple[Number, Number, Number], radius: Number, height: Number, axis: str = "z"
+    ):
         """
         :param parent: Parent Roi to generate the subset from
         :param center: Geometric center to place the cylinder
@@ -894,12 +937,14 @@ class RoiCylinder(RoiSubsetType):
         non_axial_idx = [i for i in range(3) if i != axial_idx]
 
         # Map the axis to the value corresponding to the difference from the center to that axes' outer boundary
-        diff_map = {ax: radius if ax != axis else height/2 for ax in ("x", "y", "z")}
+        diff_map = {ax: radius if ax != axis else height / 2 for ax in ("x", "y", "z")}
 
         # Axis boundaries
-        xext, yext, zext = (xc-diff_map["x"], xc+diff_map["x"]), \
-                           (yc-diff_map["y"], yc+diff_map["y"]), \
-                           (zc-diff_map["z"], zc+diff_map["z"])
+        xext, yext, zext = (
+            (xc - diff_map["x"], xc + diff_map["x"]),
+            (yc - diff_map["y"], yc + diff_map["y"]),
+            (zc - diff_map["z"], zc + diff_map["z"]),
+        )
         xyz = self.xyz
 
         # First filter out everything outside of the bounding box of the cylinder
@@ -907,14 +952,14 @@ class RoiCylinder(RoiSubsetType):
         idx = idx[n.argwhere((yext[0] < xyz[idx][:, 1]) & (xyz[idx][:, 1] < yext[1])).ravel()]
         idx = idx[n.argwhere((zext[0] < xyz[idx][:, 2]) & (xyz[idx][:, 2] < zext[1])).ravel()]
 
-        # idx = n.argwhere((xext[0] < xyz[:, 0]) & (xyz[:, 0] < xext[1]) &
-        #                  (yext[0] < xyz[:, 1]) & (xyz[:, 1] < yext[1]) &
-        #                  (zext[0] < xyz[:, 2]) & (xyz[:, 2] < zext[1])).ravel()
-
         # Then filter out everything not within the cylinder radius
-        r = la.norm((xyz[idx]-center)[:, non_axial_idx], axis=1)
+        r = la.norm((xyz[idx] - center)[:, non_axial_idx], axis=1)
         idx = idx[n.argwhere(r < radius).ravel()]
 
+        log.debug(
+            f"Created {self.__class__} with:\n\tcenter = {center}\n\tradius = {radius}\n\theight = {height}\n\taxis = {axis}"
+        )
+
         self._mask = idx
 
 
