@@ -21,6 +21,8 @@ along with APAV.  If not, see <http://www.gnu.org/licenses/>.
 """
 
 from pytest import raises
+from periodictable import elements as el
+from apav.core.isotopic import UnknownElement
 
 import apav
 from apav.utils.helpers import data_path
@@ -152,11 +154,7 @@ class TestRange:
 class TestRangeCollection:
     @classmethod
     def setup_class(cls):
-        cls.ranges = [
-            rng.Range("SiO2", (1, 2)),
-            rng.Range("Cl", (13, 14.5)),
-            rng.Range("A3W2", (20, 21))
-        ]
+        cls.ranges = [rng.Range("SiO2", (1, 2)), rng.Range("Cl", (13, 14.5)), rng.Range("A3W2", (20, 21))]
         cls.data = rng.RangeCollection(cls.ranges)
 
     def test_constructor(self):
@@ -172,7 +170,6 @@ class TestRangeCollection:
     def test_ranges(self):
         for i in self.ranges:
             assert i in self.data.ranges
-        # assert self.data.ranges == self.ranges
 
     def test_iter(self):
         for i, item in enumerate(self.data):
@@ -190,6 +187,10 @@ class TestRangeCollection:
         assert rrng.ranges[24].ion == apav.Ion("Cr2O")
         assert rrng.filepath == data_path("Si.RRNG")
 
+    def test_load_rrng(self):
+        path = data_path("Si.RRNG")
+        apav.load_rrng(path)
+
     def test_add_range(self):
         temp = rng.RangeCollection()
         item = rng.Range("CeO2", (1, 2))
@@ -231,7 +232,7 @@ class TestRangeCollection:
         assert all(Ion(i) in self.data.ions() for i in ("A3W2", "Cl", "SiO2"))
 
     def test_elements(self):
-        assert all(i in self.data.elements() for i in ("A", "W", "Cl", "Si", "O"))
+        assert all(i in self.data.elements() for i in (UnknownElement("A"), el.W, el.Cl, el.Si, el.O))
 
     def test_sorted_ranges(self):
         temp = rng.RangeCollection(self.ranges[::-1])
@@ -249,4 +250,3 @@ class TestRangeCollection:
             self.data.find_by_mass(14.5)
         with raises(ValueError):
             self.data.find_by_mass(100)
-
