@@ -20,9 +20,8 @@ You should have received a copy of the GNU General Public License
 along with APAV.  If not, see <http://www.gnu.org/licenses/>.
 """
 
-from __future__ import annotations
-
 import os
+from os.path import abspath, dirname, join
 import numpy as n
 
 import apav.utils.helpers as helpers
@@ -37,6 +36,7 @@ class NoMultiEventError(Exception):
     Raise when an operation requires multiple hit information (i.e. originates from an epos file) but
     that information is not available
     """
+
     def __init__(self):
         super().__init__("Roi has no multiple-event information")
 
@@ -46,6 +46,7 @@ class NoDetectorInfoError(Exception):
     Raise when an operation requires detector specific information (i.e. originates from an epos file) but
     that information is not available
     """
+
     def __init__(self):
         super().__init__("Roi has no detector coordinate information")
 
@@ -55,6 +56,7 @@ class NoTOFError(Exception):
     Raise when an operation requires time-of-flight information (i.e. originates from an epos file) but
     that information is not available
     """
+
     def __init__(self):
         super().__init__("Roi has no time-of-flight information")
 
@@ -63,6 +65,7 @@ class AbstractMethodError(Exception):
     """
     Raise when a call to an abstract method
     """
+
     def __init__(self):
         super().__init__("Call to abstract method is not allowed")
 
@@ -71,6 +74,7 @@ class IntervalIntersectionError(Exception):
     """
     Raise when two intervals intersect, but shouldn't
     """
+
     def __init__(self, msg: str = None):
         if msg is None:
             msg = f"Intersection between intervals is not allowed"
@@ -81,6 +85,7 @@ class IonTypeError(Exception):
     """
     Raise when an :class:`Ion` was expected but not provided
     """
+
     def __init__(self, other):
         super().__init__(f"Expected an Ion type not {type(other)}")
 
@@ -97,6 +102,26 @@ def boolean(val) -> bool:
         return val
 
 
+def dir_is_writable(filepath: str) -> str:
+    """
+    Validate whether a directory is writable
+    :param filepath: path to test writability (can be dir path or file path)
+    """
+    temp_name = "__test_path_is_writable_123"
+    temp_path = join(abspath(dirname(filepath)), temp_name)
+
+    try:
+        with open(temp_path, "w") as file:
+            file.write("This path is writable")
+    except Exception as e:
+        raise e
+    finally:
+        if os.path.exists(temp_path):
+            os.remove(temp_path)
+
+    return filepath
+
+
 def is_type(val, kind):
     if isinstance(val, kind):
         return val
@@ -118,7 +143,7 @@ def file_exists(fpath: str) -> str:
     return fpath
 
 
-def color_as_rgb(val) -> Tuple[Real, Real, Real]:
+def color_as_rgb(val) -> Tuple[Number, Number, Number]:
     """
     Validate that an input is a normalized color RGB value, convert if possible
 
@@ -147,7 +172,7 @@ def interval(val: tuple):
         raise TypeError("Invalid interval type")
     elif len(val) != 2:
         raise ValueError("Invalid interval input")
-    elif (val[1] <= val[0]):
+    elif val[1] <= val[0]:
         raise ValueError(f"Invalid interval ({val[0]} - {val[1]}), expected a sequential interval")
 
     return tuple(val)
@@ -334,7 +359,7 @@ def multiplicity_non_singles(val) -> Union[int, str]:
 
     :param val: the multiplicity to validate
     """
-    msg = f"Expected a multiplicity value of int >= 2 or \"multiples\", got {val} of type {type(val)} instead"
+    msg = f'Expected a multiplicity value of int >= 2 or "multiples", got {val} of type {type(val)} instead'
     if isinstance(val, int_types):
         if not val >= 2:
             raise ValueError(msg)
@@ -361,7 +386,7 @@ def choice(val: Any, possible_vals: Sequence[Any]):
     return val
 
 
-def all_positive_nonzero(seq: Sequence[Real]):
+def all_positive_nonzero(seq: Sequence[Number]):
     """
     Validate that all numbers of a sequence are positive and non-zero
 
@@ -370,4 +395,3 @@ def all_positive_nonzero(seq: Sequence[Real]):
     if any(i <= 0 for i in seq):
         raise ValueError("Expected a sequence of all positive non-zero values")
     return seq
-
